@@ -625,13 +625,9 @@ def execute_tests(testlist, testset):
     push_results()
 
 def get_always_tests_azure():
-    print("getting azure tests set to always run")
     count = 0
     tests = ""
-    print(azurealwaysrunset)
     for testName in azurealwaysrunset:
-        print("here")
-        print(testName)
         count = count + 1
         if encodetests == "true":
             testName = testName.encode("unicode_escape").decode()
@@ -646,11 +642,7 @@ def get_always_tests_azure():
             testName = testName.replace("=", "\=")
             testName = testName.replace("!", "\!")
             testName = testName.replace("~", "\~")
-            print(testName)
-        print("here2")
         tests = tests + testseparator + prefixtest + testName + postfixtest
-        print(tests)
-        print("here3")
     return tests
 
 
